Class: DockerEngine::Models::Container::ImageManifestDescriptor

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine/models/container.rb

Overview

Defined Under Namespace

Classes: Platform

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(annotations: nil, artifact_type: nil, data: nil, digest: nil, media_type: nil, platform: nil, size: nil, urls: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngine::Models::Container::ImageManifestDescriptor for more details.

A descriptor struct containing digest, media type, and size, as defined in the OCI Content Descriptors Specification.

Parameters:

  • annotations (Hash{Symbol=>String}, nil) (defaults to: nil) —

    Arbitrary metadata relating to the targeted content.

  • artifact_type (String, nil) (defaults to: nil) —

    ArtifactType is the IANA media type of this artifact.

  • data (String, nil) (defaults to: nil) —

    Data is an embedding of the targeted content. This is encoded as a base64

  • digest (String) (defaults to: nil) —

    The digest of the targeted content.

  • media_type (String) (defaults to: nil) —

    The media type of the object this schema refers to.

  • platform (DockerEngine::Models::Container::ImageManifestDescriptor::Platform, nil) (defaults to: nil) —

    Describes the platform which the image in the manifest runs on, as defined

  • size (Integer) (defaults to: nil) —

    The size in bytes of the blob.

  • urls (Array<String>, nil) (defaults to: nil) —

    List of URLs from which this object MAY be downloaded.



# File 'lib/docker_engine/models/container.rb', line 1757

Instance Attribute Details

#annotations ⇒ Hash{Symbol=>String}?

Arbitrary metadata relating to the targeted content.

Returns:

  • (Hash{Symbol=>String}, nil)


1709
# File 'lib/docker_engine/models/container.rb', line 1709

optional :annotations, DockerEngine::Internal::Type::HashOf[String], nil?: true

#artifact_type ⇒ String?

ArtifactType is the IANA media type of this artifact.

Returns:

  • (String, nil)


1715
# File 'lib/docker_engine/models/container.rb', line 1715

optional :artifact_type, String, api_name: :artifactType, nil?: true

#data ⇒ String?

Data is an embedding of the targeted content. This is encoded as a base64 string when marshalled to JSON (automatically, by encoding/json). If present, Data can be used directly to avoid fetching the targeted content.

Returns:

  • (String, nil)


1723
# File 'lib/docker_engine/models/container.rb', line 1723

optional :data, String, nil?: true

#digest ⇒ String?

The digest of the targeted content.

Returns:

  • (String, nil)


1729
# File 'lib/docker_engine/models/container.rb', line 1729

optional :digest, String

#media_type ⇒ String?

The media type of the object this schema refers to.

Returns:

  • (String, nil)


1735
# File 'lib/docker_engine/models/container.rb', line 1735

optional :media_type, String, api_name: :mediaType

#platform ⇒ DockerEngine::Models::Container::ImageManifestDescriptor::Platform?

Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.



1743
# File 'lib/docker_engine/models/container.rb', line 1743

optional :platform, -> { DockerEngine::Container::ImageManifestDescriptor::Platform }, nil?: true

#size ⇒ Integer?

The size in bytes of the blob.

Returns:

  • (Integer, nil)


1749
# File 'lib/docker_engine/models/container.rb', line 1749

optional :size, Integer

#urls ⇒ Array<String>?

List of URLs from which this object MAY be downloaded.

Returns:

  • (Array<String>, nil)


1755
# File 'lib/docker_engine/models/container.rb', line 1755

optional :urls, DockerEngine::Internal::Type::ArrayOf[String], nil?: true