Class: DockerEngine::Models::Container::NetworkSettings

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine/models/container.rb

Overview

See Also:

Defined Under Namespace

Classes: Network, Port

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(i_pv4_address: nil, i_pv6_address: nil, link_local_ips: nil) ⇒ Object

EndpointIPAMConfig represents an endpoint's IPAM configuration.

Parameters:

  • i_pv4_address (String) (defaults to: nil)
  • i_pv6_address (String) (defaults to: nil)
  • link_local_ips (Array<String>) (defaults to: nil)


# File 'lib/docker_engine/models/container.rb', line 2165

Instance Attribute Details

#networks ⇒ Hash{Symbol=>DockerEngine::Models::Container::NetworkSettings::Network}?

Information about all networks that the container is connected to.



1959
1960
1961
1962
1963
# File 'lib/docker_engine/models/container.rb', line 1959

optional :networks,
-> {
  DockerEngine::Internal::Type::HashOf[DockerEngine::Container::NetworkSettings::Network]
},
api_name: :Networks

#ports ⇒ Hash{Symbol=>Array<DockerEngine::Models::Container::NetworkSettings::Port>}?

PortMap describes the mapping of container ports to host ports, using the container's port-number and protocol as key in the format <port>/<protocol>, for example, 80/udp.

If a container's port is mapped for multiple protocols, separate entries are added to the mapping table.

Returns:



1974
1975
1976
1977
1978
# File 'lib/docker_engine/models/container.rb', line 1974

optional :ports,
-> {
  DockerEngine::Internal::Type::HashOf[DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::NetworkSettings::Port]]
},
api_name: :Ports

#sandbox_id ⇒ String?

SandboxID uniquely represents a container's network stack.

Returns:

  • (String, nil)


1984
# File 'lib/docker_engine/models/container.rb', line 1984

optional :sandbox_id, String, api_name: :SandboxID

#sandbox_key ⇒ String?

SandboxKey is the full path of the netns handle

Returns:

  • (String, nil)


1990
# File 'lib/docker_engine/models/container.rb', line 1990

optional :sandbox_key, String, api_name: :SandboxKey