Class: DockerEngine::Models::Container::State::Health
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngine::Models::Container::State::Health
- Defined in:
- lib/docker_engine/models/container.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#failing_streak ⇒ Integer?
FailingStreak is the number of consecutive failures.
-
#log ⇒ Array<DockerEngine::Models::Container::State::Health::Log, nil>?
Log contains the last few results (oldest first).
-
#status ⇒ Symbol, ...
Status is one of
none,starting,healthyorunhealthy.
Instance Method Summary collapse
-
#initialize(end_: nil, exit_code: nil, output: nil, start: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Log for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(end_: nil, exit_code: nil, output: nil, start: nil) ⇒ Object
Some parameter documentations has been truncated, see Log for more details.
HealthcheckResult stores information about a single run of a healthcheck probe
|
|
# File 'lib/docker_engine/models/container.rb', line 2384
|
Instance Attribute Details
#failing_streak ⇒ Integer?
FailingStreak is the number of consecutive failures
2316 |
# File 'lib/docker_engine/models/container.rb', line 2316 optional :failing_streak, Integer, api_name: :FailingStreak |
#log ⇒ Array<DockerEngine::Models::Container::State::Health::Log, nil>?
Log contains the last few results (oldest first)
2322 2323 2324 2325 2326 2327 |
# File 'lib/docker_engine/models/container.rb', line 2322 optional :log, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::State::Health::Log, nil?: true] }, api_name: :Log |
#status ⇒ Symbol, ...
Status is one of none, starting, healthy or unhealthy
- "none" Indicates there is no healthcheck
- "starting" Starting indicates that the container is not yet ready
- "healthy" Healthy indicates that the container is running correctly
- "unhealthy" Unhealthy indicates that the container has a problem
2338 |
# File 'lib/docker_engine/models/container.rb', line 2338 optional :status, enum: -> { DockerEngine::Container::State::Health::Status }, api_name: :Status |