Class: DockerEngine::Models::Container::State::Health::Log

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine/models/container.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(failing_streak: nil, log: nil, status: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngine::Models::Container::State::Health for more details.

Health stores information about the container's healthcheck results.

Parameters:



2352
2353
2354
2355
2356
2357
2358
2359
2360
2361
2362
2363
2364
2365
2366
2367
2368
2369
2370
2371
2372
2373
2374
2375
2376
2377
2378
2379
2380
2381
2382
2383
2384
2385
2386
2387
2388
2389
2390
2391
2392
2393
2394
2395
2396
2397
# File 'lib/docker_engine/models/container.rb', line 2352

class Log < DockerEngine::Internal::Type::BaseModel
  # @!attribute end_
  #   Date and time at which this check ended in
  #   [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
  #
  #   @return [String, nil]
  optional :end_, String, api_name: :End

  # @!attribute exit_code
  #   ExitCode meanings:
  #
  #   - `0` healthy
  #   - `1` unhealthy
  #   - `2` reserved (considered unhealthy)
  #   - other values: error running probe
  #
  #   @return [Integer, nil]
  optional :exit_code, Integer, api_name: :ExitCode

  # @!attribute output
  #   Output from last check
  #
  #   @return [String, nil]
  optional :output, String, api_name: :Output

  # @!attribute start
  #   Date and time at which this check started in
  #   [RFC 3339](https://www.ietf.org/rfc/rfc3339.txt) format with nano-seconds.
  #
  #   @return [Time, nil]
  optional :start, Time, api_name: :Start

  # @!method initialize(end_: nil, exit_code: nil, output: nil, start: nil)
  #   Some parameter documentations has been truncated, see
  #   {DockerEngine::Models::Container::State::Health::Log} for more details.
  #
  #   HealthcheckResult stores information about a single run of a healthcheck probe
  #
  #   @param end_ [String] Date and time at which this check ended in
  #
  #   @param exit_code [Integer] ExitCode meanings:
  #
  #   @param output [String] Output from last check
  #
  #   @param start [Time] Date and time at which this check started in
end

Instance Attribute Details

#end_ ⇒ String?

Date and time at which this check ended in RFC 3339 format with nano-seconds.

Returns:

  • (String, nil)


2358
# File 'lib/docker_engine/models/container.rb', line 2358

optional :end_, String, api_name: :End

#exit_code ⇒ Integer?

ExitCode meanings:

  • 0 healthy
  • 1 unhealthy
  • 2 reserved (considered unhealthy)
  • other values: error running probe

Returns:

  • (Integer, nil)


2369
# File 'lib/docker_engine/models/container.rb', line 2369

optional :exit_code, Integer, api_name: :ExitCode

#output ⇒ String?

Output from last check

Returns:

  • (String, nil)


2375
# File 'lib/docker_engine/models/container.rb', line 2375

optional :output, String, api_name: :Output

#start ⇒ Time?

Date and time at which this check started in RFC 3339 format with nano-seconds.

Returns:

  • (Time, nil)


2382
# File 'lib/docker_engine/models/container.rb', line 2382

optional :start, Time, api_name: :Start