Class: DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount::BindOptions
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount::BindOptions
- Defined in:
- lib/docker_engine/models/container_create_params.rb
Overview
Defined Under Namespace
Modules: Propagation
Instance Attribute Summary collapse
-
#create_mountpoint ⇒ Boolean?
Create mount point on host if missing.
-
#non_recursive ⇒ Boolean?
Disable recursive bind mount.
-
#propagation ⇒ Symbol, ...
A propagation mode with the value
[r]private,[r]shared, or[r]slave. -
#read_only_force_recursive ⇒ Boolean?
Raise an error if the mount cannot be made recursively read-only.
-
#read_only_non_recursive ⇒ Boolean?
Make the mount non-recursively read-only, but still leave the mount recursive (unless NonRecursive is set to
truein conjunction).
Instance Method Summary collapse
-
#initialize(create_mountpoint: nil, non_recursive: nil, propagation: nil, read_only_force_recursive: nil, read_only_non_recursive: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see BindOptions for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(create_mountpoint: nil, non_recursive: nil, propagation: nil, read_only_force_recursive: nil, read_only_non_recursive: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount::BindOptions for more details.
Optional configuration for the bind type.
|
|
# File 'lib/docker_engine/models/container_create_params.rb', line 1232
|
Instance Attribute Details
#create_mountpoint ⇒ Boolean?
Create mount point on host if missing
1193 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1193 optional :create_mountpoint, DockerEngine::Internal::Type::Boolean, api_name: :CreateMountpoint |
#non_recursive ⇒ Boolean?
Disable recursive bind mount.
1199 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1199 optional :non_recursive, DockerEngine::Internal::Type::Boolean, api_name: :NonRecursive |
#propagation ⇒ Symbol, ...
A propagation mode with the value [r]private, [r]shared, or [r]slave.
1205 1206 1207 1208 1209 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1205 optional :propagation, enum: -> { DockerEngine::ContainerCreateParams::Config::HostConfig::Mount::BindOptions::Propagation }, api_name: :Propagation |
#read_only_force_recursive ⇒ Boolean?
Raise an error if the mount cannot be made recursively read-only.
1215 1216 1217 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1215 optional :read_only_force_recursive, DockerEngine::Internal::Type::Boolean, api_name: :ReadOnlyForceRecursive |
#read_only_non_recursive ⇒ Boolean?
Make the mount non-recursively read-only, but still leave the mount recursive
(unless NonRecursive is set to true in conjunction).
Added in v1.44, before that version all read-only mounts were non-recursive by
default. To match the previous behaviour this will default to true for clients
on versions prior to v1.44.
1228 1229 1230 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1228 optional :read_only_non_recursive, DockerEngine::Internal::Type::Boolean, api_name: :ReadOnlyNonRecursive |