Class: DockerEngine::Models::ContainerCreateParams::Config::NetworkingConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine/models/container_create_params.rb

Defined Under Namespace

Classes: EndpointsConfig

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from DockerEngine::Internal::Type::BaseModel

Instance Attribute Details

#endpoints_config ⇒ Hash{Symbol=>DockerEngine::Models::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig}?

A mapping of network name to endpoint configuration for that network. The endpoint configuration can be left empty to connect to that network with no particular endpoint configuration.



1525
1526
1527
1528
1529
# File 'lib/docker_engine/models/container_create_params.rb', line 1525

optional :endpoints_config,
-> {
  DockerEngine::Internal::Type::HashOf[DockerEngine::ContainerCreateParams::Config::NetworkingConfig::EndpointsConfig]
},
api_name: :EndpointsConfig