Class: DockerEngine::Models::ContainerListParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine/models/container_list_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(all: nil, filters: nil, limit: nil, size: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngine::Models::ContainerListParams for more details.

Parameters:

  • all (Boolean) (defaults to: nil) —

    Return all containers. By default, only running containers are shown.

  • filters (String) (defaults to: nil) —

    Filters to process on the container list, encoded as JSON (a

  • limit (Integer) (defaults to: nil) —

    Return this number of most recently created containers, including

  • size (Boolean) (defaults to: nil) —

    Return the size of container as fields SizeRw and SizeRootFs.

  • request_options (DockerEngine::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine/models/container_list_params.rb', line 55

Instance Attribute Details

#all ⇒ Boolean?

Return all containers. By default, only running containers are shown.

Returns:

  • (Boolean, nil)


14
# File 'lib/docker_engine/models/container_list_params.rb', line 14

optional :all, DockerEngine::Internal::Type::Boolean

#filters ⇒ String?

Filters to process on the container list, encoded as JSON (a map[string][]string). For example, {"status": ["paused"]} will only return paused containers.

Available filters:

  • ancestor=(<image-name>[:<tag>], <image id>, or <image@digest>)
  • before=(<container id> or <container name>)
  • expose=(<port>[/<proto>]|<startport-endport>/[<proto>])
  • exited=<int> containers with exit code of <int>
  • health=(starting|healthy|unhealthy|none)
  • id=<ID> a container's ID
  • isolation=(default|process|hyperv) (Windows daemon only)
  • is-task=(true|false)
  • label=key or label="key=value" of a container label
  • name=<name> a container's name
  • network=(<network id> or <network name>)
  • publish=(<port>[/<proto>]|<startport-endport>/[<proto>])
  • since=(<container id> or <container name>)
  • status=(created|restarting|running|removing|paused|exited|dead)
  • volume=(<volume name> or <mount point destination>)

Returns:

  • (String, nil)


40
# File 'lib/docker_engine/models/container_list_params.rb', line 40

optional :filters, String

#limit ⇒ Integer?

Return this number of most recently created containers, including non-running ones.

Returns:

  • (Integer, nil)


47
# File 'lib/docker_engine/models/container_list_params.rb', line 47

optional :limit, Integer

#size ⇒ Boolean?

Return the size of container as fields SizeRw and SizeRootFs.

Returns:

  • (Boolean, nil)


53
# File 'lib/docker_engine/models/container_list_params.rb', line 53

optional :size, DockerEngine::Internal::Type::Boolean