Class: DockerEngine::Models::CreateRequest::ClusterVolumeSpec::AccessMode
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngine::Models::CreateRequest::ClusterVolumeSpec::AccessMode
- Defined in:
- lib/docker_engine/models/create_request.rb
Overview
Defined Under Namespace
Modules: Availability, Scope, Sharing Classes: AccessibilityRequirements, CapacityRange, Secret
Instance Attribute Summary collapse
-
#accessibility_requirements ⇒ DockerEngine::Models::CreateRequest::ClusterVolumeSpec::AccessMode::AccessibilityRequirements?
Requirements for the accessible topology of the volume.
-
#availability ⇒ Symbol, ...
The availability of the volume for use in tasks.
-
#capacity_range ⇒ DockerEngine::Models::CreateRequest::ClusterVolumeSpec::AccessMode::CapacityRange?
The desired capacity that the volume should be created with.
-
#mount_volume ⇒ Object?
Options for using this volume as a Mount-type volume.
-
#scope ⇒ Symbol, ...
The set of nodes this volume can be used on at one time.
-
#secrets ⇒ Array<DockerEngine::Models::CreateRequest::ClusterVolumeSpec::AccessMode::Secret>?
Swarm Secrets that are passed to the CSI storage plugin when operating on this volume.
-
#sharing ⇒ Symbol, ...
The number and way that different tasks can use this volume at one time.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(key: nil, secret: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Secret for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(key: nil, secret: nil) ⇒ Object
Some parameter documentations has been truncated, see Secret for more details.
One cluster volume secret entry. Defines a key-value pair that is passed to the plugin.
|
|
# File 'lib/docker_engine/models/create_request.rb', line 175
|
Instance Attribute Details
#accessibility_requirements ⇒ DockerEngine::Models::CreateRequest::ClusterVolumeSpec::AccessMode::AccessibilityRequirements?
Requirements for the accessible topology of the volume. These fields are optional. For an in-depth description of what these fields mean, see the CSI specification.
93 94 95 96 97 |
# File 'lib/docker_engine/models/create_request.rb', line 93 optional :accessibility_requirements, -> { DockerEngine::CreateRequest::ClusterVolumeSpec::AccessMode::AccessibilityRequirements }, api_name: :AccessibilityRequirements |
#availability ⇒ Symbol, ...
The availability of the volume for use in tasks.
activeThe volume is fully available for scheduling on the clusterpauseNo new workloads should use the volume, but existing workloads are not stopped.drainAll workloads using this volume should be stopped and rescheduled, and no new ones should be started.
109 110 111 |
# File 'lib/docker_engine/models/create_request.rb', line 109 optional :availability, enum: -> { DockerEngine::CreateRequest::ClusterVolumeSpec::AccessMode::Availability }, api_name: :Availability |
#capacity_range ⇒ DockerEngine::Models::CreateRequest::ClusterVolumeSpec::AccessMode::CapacityRange?
The desired capacity that the volume should be created with. If empty, the plugin will decide the capacity.
118 119 120 |
# File 'lib/docker_engine/models/create_request.rb', line 118 optional :capacity_range, -> { DockerEngine::CreateRequest::ClusterVolumeSpec::AccessMode::CapacityRange }, api_name: :CapacityRange |
#mount_volume ⇒ Object?
Options for using this volume as a Mount-type volume.
Either MountVolume or BlockVolume, but not both, must be
present.
properties: FsType: type: "string" description: | Specifies the filesystem type for the mount volume. Optional. MountFlags: type: "array" description: | Flags to pass when mounting the volume. Optional. items: type: "string" BlockVolume: type: "object" description: | Options for using this volume as a Block-type volume. Intentionally empty.
135 |
# File 'lib/docker_engine/models/create_request.rb', line 135 optional :mount_volume, DockerEngine::Internal::Type::Unknown, api_name: :MountVolume |
#scope ⇒ Symbol, ...
The set of nodes this volume can be used on at one time.
singleThe volume may only be scheduled to one node at a time.multithe volume may be scheduled to any supported number of nodes at a time.
145 146 147 |
# File 'lib/docker_engine/models/create_request.rb', line 145 optional :scope, enum: -> { DockerEngine::CreateRequest::ClusterVolumeSpec::AccessMode::Scope }, api_name: :Scope |
#secrets ⇒ Array<DockerEngine::Models::CreateRequest::ClusterVolumeSpec::AccessMode::Secret>?
Swarm Secrets that are passed to the CSI storage plugin when operating on this volume.
154 155 156 157 158 |
# File 'lib/docker_engine/models/create_request.rb', line 154 optional :secrets, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::CreateRequest::ClusterVolumeSpec::AccessMode::Secret] }, api_name: :Secrets |
#sharing ⇒ Symbol, ...
The number and way that different tasks can use this volume at one time.
noneThe volume may only be used by one task at a time.readonlyThe volume may be used by any number of tasks, but they all must mount the volume as readonlyonewriterThe volume may be used by any number of tasks, but only one may mount it as read/write.allThe volume may have any number of readers and writers.
171 172 173 |
# File 'lib/docker_engine/models/create_request.rb', line 171 optional :sharing, enum: -> { DockerEngine::CreateRequest::ClusterVolumeSpec::AccessMode::Sharing }, api_name: :Sharing |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine/models/create_request.rb', line 245
|