Class: DockerEngine::Models::Image::Manifest

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine/models/image.rb

Defined Under Namespace

Modules: Kind Classes: AttestationData, Descriptor, ImageData, Size

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(for_:) ⇒ Object

Some parameter documentations has been truncated, see AttestationData for more details.

The image data for the attestation manifest. This field is only populated when Kind is "attestation".

Parameters:

  • for_ (String) —

    The digest of the image manifest that this attestation is for.



# File 'lib/docker_engine/models/image.rb', line 1020

Instance Attribute Details

#attestation_data ⇒ DockerEngine::Models::Image::Manifest::AttestationData?

The image data for the attestation manifest. This field is only populated when Kind is "attestation".



1003
1004
1005
1006
# File 'lib/docker_engine/models/image.rb', line 1003

optional :attestation_data,
-> { DockerEngine::Image::Manifest::AttestationData },
api_name: :AttestationData,
nil?: true

#available ⇒ Boolean

Indicates whether all the child content (image config, layers) is fully available locally.

Returns:

  • (Boolean)


966
# File 'lib/docker_engine/models/image.rb', line 966

required :available, DockerEngine::Internal::Type::Boolean, api_name: :Available

#descriptor ⇒ DockerEngine::Models::Image::Manifest::Descriptor

A descriptor struct containing digest, media type, and size, as defined in the OCI Content Descriptors Specification.



973
# File 'lib/docker_engine/models/image.rb', line 973

required :descriptor, -> { DockerEngine::Image::Manifest::Descriptor }, api_name: :Descriptor

#id ⇒ String

ID is the content-addressable ID of an image and is the same as the digest of the image manifest.

Returns:

  • (String)


980
# File 'lib/docker_engine/models/image.rb', line 980

required :id, String, api_name: :ID

#image_data ⇒ DockerEngine::Models::Image::Manifest::ImageData?

The image data for the image manifest. This field is only populated when Kind is "image".



1013
1014
1015
1016
1017
1018
# File 'lib/docker_engine/models/image.rb', line 1013

optional :image_data,
-> {
  DockerEngine::Image::Manifest::ImageData
},
api_name: :ImageData,
nil?: true

#kind ⇒ Symbol, DockerEngine::Models::Image::Manifest::Kind

The kind of the manifest.

kind description
image Image manifest that can be used to start a container.
attestation Attestation manifest produced by the Buildkit builder for a specific image manifest.


991
# File 'lib/docker_engine/models/image.rb', line 991

required :kind, enum: -> { DockerEngine::Image::Manifest::Kind }, api_name: :Kind

#size ⇒ DockerEngine::Models::Image::Manifest::Size



996
# File 'lib/docker_engine/models/image.rb', line 996

required :size, -> { DockerEngine::Image::Manifest::Size }, api_name: :Size

Class Method Details

.values ⇒ Array<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/docker_engine/models/image.rb', line 1187