Class: DockerEngine::Models::Image::Manifest::Size

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine/models/image.rb

Overview

See Also:

Instance Attribute Summary collapse

Method Summary

Methods inherited from Internal::Type::BaseModel

#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from DockerEngine::Internal::Type::BaseModel

Instance Attribute Details

#content ⇒ Integer

Content is the size (in bytes) of all the locally present content in the content store (e.g. image config, layers) referenced by this manifest and its children. This only includes blobs in the content store.

Returns:

  • (Integer)


1199
# File 'lib/docker_engine/models/image.rb', line 1199

required :content, Integer, api_name: :Content

#total ⇒ Integer

Total is the total size (in bytes) of all the locally present data (both distributable and non-distributable) that's related to this manifest and its children. This equal to the sum of [Content] size AND all the sizes in the [Size] struct present in the Kind-specific data struct. For example, for an image kind (Kind == "image") this would include the size of the image content and unpacked image snapshots ([Size.Content] + [ImageData.Size.Unpacked]).

Returns:

  • (Integer)


1210
# File 'lib/docker_engine/models/image.rb', line 1210

required :total, Integer, api_name: :Total