Class: DockerEngine::Models::Image::Metadata
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngine::Models::Image::Metadata
- Defined in:
- lib/docker_engine/models/image.rb
Overview
Instance Attribute Summary collapse
-
#last_tag_time ⇒ String?
Date and time at which the image was last tagged in RFC 3339 format with nano-seconds.
Method Summary
Methods inherited from Internal::Type::BaseModel
#==, ==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from DockerEngine::Internal::Type::BaseModel
Instance Attribute Details
#last_tag_time ⇒ String?
Date and time at which the image was last tagged in RFC 3339 format with nano-seconds.
This information is only available if the image was tagged locally, and omitted otherwise.
1361 |
# File 'lib/docker_engine/models/image.rb', line 1361 optional :last_tag_time, String, api_name: :LastTagTime, nil?: true |