Class: DockerEngine::Models::Inspect
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngine::Models::Inspect
- Defined in:
- lib/docker_engine/models/inspect.rb
Overview
Defined Under Namespace
Classes: Descriptor, Platform
Instance Attribute Summary collapse
-
#descriptor ⇒ DockerEngine::Models::Inspect::Descriptor
A descriptor struct containing digest, media type, and size, as defined in the OCI Content Descriptors Specification.
-
#platforms ⇒ Array<DockerEngine::Models::Inspect::Platform, nil>
An array containing all platforms supported by the image.
Instance Method Summary collapse
-
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Descriptor::Platform for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngine::Models::Inspect::Descriptor::Platform for more details.
Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.
|
|
# File 'lib/docker_engine/models/inspect.rb', line 22
|
Instance Attribute Details
#descriptor ⇒ DockerEngine::Models::Inspect::Descriptor
A descriptor struct containing digest, media type, and size, as defined in the OCI Content Descriptors Specification.
12 |
# File 'lib/docker_engine/models/inspect.rb', line 12 required :descriptor, -> { DockerEngine::Inspect::Descriptor }, api_name: :Descriptor |
#platforms ⇒ Array<DockerEngine::Models::Inspect::Platform, nil>
An array containing all platforms supported by the image.
18 19 20 |
# File 'lib/docker_engine/models/inspect.rb', line 18 required :platforms, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::Inspect::Platform, nil?: true] }, api_name: :Platforms |