Class: DockerEngine::Models::Service::JobStatus

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/docker_engine/models/service.rb

Overview

See Also:

Defined Under Namespace

Classes: JobIteration

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(job_iteration: nil, last_execution: nil) ⇒ Object

Some parameter documentations has been truncated, see DockerEngine::Models::Service::JobStatus for more details.

The status of the service when it is in one of ReplicatedJob or GlobalJob modes. Absent on Replicated and Global mode services. The JobIteration is an ObjectVersion, but unlike the Service's version, does not need to be sent with an update request.

Parameters:

  • job_iteration (DockerEngine::Models::Service::JobStatus::JobIteration) (defaults to: nil) —

    The version number of the object such as node, service, etc. This is needed

  • last_execution (String) (defaults to: nil) —

    The last time, as observed by the server, that this job was



# File 'lib/docker_engine/models/service.rb', line 380

Instance Attribute Details

#job_iteration ⇒ DockerEngine::Models::Service::JobStatus::JobIteration?

The version number of the object such as node, service, etc. This is needed to avoid conflicting writes. The client must send the version number along with the modified specification when updating these objects.

This approach ensures safe concurrency and determinism in that the change on the object may not be applied if the version number has changed from the last read. In other words, if two update requests specify the same base version, only one of the requests can succeed. As a result, two separate update requests that happen at the same time will not unintentionally overwrite each other.



368
369
370
371
372
# File 'lib/docker_engine/models/service.rb', line 368

optional :job_iteration,
-> {
  DockerEngine::Service::JobStatus::JobIteration
},
api_name: :JobIteration

#last_execution ⇒ String?

The last time, as observed by the server, that this job was started.

Returns:

  • (String, nil)


378
# File 'lib/docker_engine/models/service.rb', line 378

optional :last_execution, String, api_name: :LastExecution