Class: DockerEngine::Models::SwarmInitParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngine::Models::SwarmInitParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/docker_engine/models/swarm_init_params.rb
Overview
Instance Attribute Summary collapse
-
#advertise_addr ⇒ String?
Externally reachable address advertised to other nodes.
-
#data_path_addr ⇒ String?
Address or interface to use for data path traffic (format:
<ip|interface>), for example,192.168.1.1, or an interface, likeeth0. -
#data_path_port ⇒ Integer?
DataPathPort specifies the data path port number for data traffic.
-
#default_addr_pool ⇒ Array<String>?
Default Address Pool specifies default subnet pools for global scope networks.
-
#force_new_cluster ⇒ Boolean?
Force creation of a new swarm.
-
#listen_addr ⇒ String?
Listen address used for inter-manager communication, as well as determining the networking interface used for the VXLAN Tunnel Endpoint (VTEP).
-
#spec ⇒ DockerEngine::Models::Spec?
User modifiable swarm configuration.
-
#subnet_size ⇒ Integer?
SubnetSize specifies the subnet size of the networks created from the default subnet pool.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(advertise_addr: nil, data_path_addr: nil, data_path_port: nil, default_addr_pool: nil, force_new_cluster: nil, listen_addr: nil, spec: nil, subnet_size: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see SwarmInitParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(advertise_addr: nil, data_path_addr: nil, data_path_port: nil, default_addr_pool: nil, force_new_cluster: nil, listen_addr: nil, spec: nil, subnet_size: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see DockerEngine::Models::SwarmInitParams for more details.
|
|
# File 'lib/docker_engine/models/swarm_init_params.rb', line 76
|
Instance Attribute Details
#advertise_addr ⇒ String?
Externally reachable address advertised to other nodes. This can either be an
address/port combination in the form 192.168.1.1:4567, or an interface
followed by a port number, like eth0:4567. If the port number is omitted, the
port number from the listen address is used. If AdvertiseAddr is not
specified, it will be automatically detected when possible.
18 |
# File 'lib/docker_engine/models/swarm_init_params.rb', line 18 optional :advertise_addr, String, api_name: :AdvertiseAddr |
#data_path_addr ⇒ String?
Address or interface to use for data path traffic (format: <ip|interface>),
for example, 192.168.1.1, or an interface, like eth0. If DataPathAddr is
unspecified, the same address as AdvertiseAddr is used.
The DataPathAddr specifies the address that global scope network drivers will
publish towards other nodes in order to reach the containers running on this
node. Using this parameter it is possible to separate the container data traffic
from the management traffic of the cluster.
31 |
# File 'lib/docker_engine/models/swarm_init_params.rb', line 31 optional :data_path_addr, String, api_name: :DataPathAddr |
#data_path_port ⇒ Integer?
DataPathPort specifies the data path port number for data traffic. Acceptable port range is 1024 to 49151. if no port is set or is set to 0, default port 4789 will be used.
39 |
# File 'lib/docker_engine/models/swarm_init_params.rb', line 39 optional :data_path_port, Integer, api_name: :DataPathPort |
#default_addr_pool ⇒ Array<String>?
Default Address Pool specifies default subnet pools for global scope networks.
45 |
# File 'lib/docker_engine/models/swarm_init_params.rb', line 45 optional :default_addr_pool, DockerEngine::Internal::Type::ArrayOf[String], api_name: :DefaultAddrPool |
#force_new_cluster ⇒ Boolean?
Force creation of a new swarm.
51 |
# File 'lib/docker_engine/models/swarm_init_params.rb', line 51 optional :force_new_cluster, DockerEngine::Internal::Type::Boolean, api_name: :ForceNewCluster |
#listen_addr ⇒ String?
Listen address used for inter-manager communication, as well as determining the
networking interface used for the VXLAN Tunnel Endpoint (VTEP). This can either
be an address/port combination in the form 192.168.1.1:4567, or an interface
followed by a port number, like eth0:4567. If the port number is omitted, the
default swarm listening port is used.
61 |
# File 'lib/docker_engine/models/swarm_init_params.rb', line 61 optional :listen_addr, String, api_name: :ListenAddr |
#spec ⇒ DockerEngine::Models::Spec?
User modifiable swarm configuration.
67 |
# File 'lib/docker_engine/models/swarm_init_params.rb', line 67 optional :spec, -> { DockerEngine::Spec }, api_name: :Spec |
#subnet_size ⇒ Integer?
SubnetSize specifies the subnet size of the networks created from the default subnet pool.
74 |
# File 'lib/docker_engine/models/swarm_init_params.rb', line 74 optional :subnet_size, Integer, api_name: :SubnetSize |