Class: DockerEngine::Models::SystemEventsParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/docker_engine/models/system_events_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(filters: nil, since: nil, until_: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see DockerEngine::Models::SystemEventsParams for more details.

Parameters:

  • filters (String) (defaults to: nil) —

    A JSON encoded value of filters (a map[string][]string) to process on the even

  • since (String) (defaults to: nil) —

    Show events created since this timestamp then stream new events.

  • until_ (String) (defaults to: nil) —

    Show events created until this timestamp then stop streaming.

  • request_options (DockerEngine::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/docker_engine/models/system_events_params.rb', line 45

Instance Attribute Details

#filters ⇒ String?

A JSON encoded value of filters (a map[string][]string) to process on the event list. Available filters:

  • config=<string> config name or ID
  • container=<string> container name or ID
  • daemon=<string> daemon name or ID
  • event=<string> event type
  • image=<string> image name or ID
  • label=<string> image or container label
  • network=<string> network name or ID
  • node=<string> node ID
  • plugin= plugin name or ID
  • scope= local or swarm
  • secret=<string> secret name or ID
  • service=<string> service name or ID
  • type=<string> object to filter by, one of container, image, volume, network, daemon, plugin, node, service, secret or config
  • volume=<string> volume name

Returns:

  • (String, nil)


31
# File 'lib/docker_engine/models/system_events_params.rb', line 31

optional :filters, String

#since ⇒ String?

Show events created since this timestamp then stream new events.

Returns:

  • (String, nil)


37
# File 'lib/docker_engine/models/system_events_params.rb', line 37

optional :since, String

#until_ ⇒ String?

Show events created until this timestamp then stop streaming.

Returns:

  • (String, nil)


43
# File 'lib/docker_engine/models/system_events_params.rb', line 43

optional :until_, String