Module: DockerEngine::Models::Volume::ClusterVolume::Spec::AccessMode::Sharing
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/docker_engine/models/volume.rb
Overview
The number and way that different tasks can use this volume at one time.
noneThe volume may only be used by one task at a time.readonlyThe volume may be used by any number of tasks, but they all must mount the volume as readonlyonewriterThe volume may be used by any number of tasks, but only one may mount it as read/write.allThe volume may have any number of readers and writers.
Constant Summary collapse
- NONE =
:none- READONLY =
:readonly- ONEWRITER =
:onewriter- ALL =
:all
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info