Module: DockerEngine::Models::VolumeUpdateParams::Spec::AccessMode::Availability
- Extended by:
- Internal::Type::Enum
- Defined in:
- lib/docker_engine/models/volume_update_params.rb
Overview
The availability of the volume for use in tasks.
activeThe volume is fully available for scheduling on the clusterpauseNo new workloads should use the volume, but existing workloads are not stopped.drainAll workloads using this volume should be stopped and rescheduled, and no new ones should be started.
Constant Summary collapse
- ACTIVE =
:active- PAUSE =
:pause- DRAIN =
:drain
Method Summary
Methods included from Internal::Type::Enum
==, ===, coerce, dump, hash, inspect, to_sorbet_type, values
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info