Class: DockerEngine::Models::ConnectRequest::EndpointConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngine::Models::ConnectRequest::EndpointConfig
- Defined in:
- lib/docker_engine/models/connect_request.rb
Overview
Defined Under Namespace
Classes: IpamConfig
Instance Attribute Summary collapse
- #aliases ⇒ Array<String>?
-
#dns_names ⇒ Array<String>?
List of all DNS names an endpoint has on a specific network.
-
#driver_opts ⇒ Hash{Symbol=>String}?
DriverOpts is a mapping of driver options and values.
-
#endpoint_id ⇒ String?
Unique ID for the service endpoint in a Sandbox.
-
#gateway ⇒ String?
Gateway address for this network.
-
#global_i_pv6_address ⇒ String?
Global IPv6 address.
-
#global_i_pv6_prefix_len ⇒ Integer?
Mask length of the global IPv6 address.
-
#gw_priority ⇒ Integer?
This property determines which endpoint will provide the default gateway for a container.
-
#i_pv6_gateway ⇒ String?
IPv6 gateway address.
-
#ip_address ⇒ String?
IPv4 address.
-
#ip_prefix_len ⇒ Integer?
Mask length of the IPv4 address.
-
#ipam_config ⇒ DockerEngine::Models::ConnectRequest::EndpointConfig::IpamConfig?
EndpointIPAMConfig represents an endpoint's IPAM configuration.
- #links ⇒ Array<String>?
-
#mac_address ⇒ String?
MAC address for the endpoint on this network.
-
#network_id ⇒ String?
Unique ID of the network.
Instance Method Summary collapse
-
#initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see EndpointConfig for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(aliases: nil, dns_names: nil, driver_opts: nil, endpoint_id: nil, gateway: nil, global_i_pv6_address: nil, global_i_pv6_prefix_len: nil, gw_priority: nil, ip_address: nil, ipam_config: nil, ip_prefix_len: nil, i_pv6_gateway: nil, links: nil, mac_address: nil, network_id: nil) ⇒ Object
Some parameter documentations has been truncated, see DockerEngine::Models::ConnectRequest::EndpointConfig for more details.
Configuration for a network endpoint.
|
|
# File 'lib/docker_engine/models/connect_request.rb', line 134
|
Instance Attribute Details
#aliases ⇒ Array<String>?
35 |
# File 'lib/docker_engine/models/connect_request.rb', line 35 optional :aliases, DockerEngine::Internal::Type::ArrayOf[String], api_name: :Aliases |
#dns_names ⇒ Array<String>?
List of all DNS names an endpoint has on a specific network. This list is based on the container name, network aliases, container short ID, and hostname.
These DNS names are non-fully qualified but can contain several dots. You can
get fully qualified DNS names by appending .<network-name>. For instance, if
container name is my.ctr and the network is named testnet, DNSNames will
contain my.ctr and the FQDN will be my.ctr.testnet.
47 |
# File 'lib/docker_engine/models/connect_request.rb', line 47 optional :dns_names, DockerEngine::Internal::Type::ArrayOf[String], api_name: :DNSNames |
#driver_opts ⇒ Hash{Symbol=>String}?
DriverOpts is a mapping of driver options and values. These options are passed directly to the driver and are driver specific.
54 |
# File 'lib/docker_engine/models/connect_request.rb', line 54 optional :driver_opts, DockerEngine::Internal::Type::HashOf[String], api_name: :DriverOpts, nil?: true |
#endpoint_id ⇒ String?
Unique ID for the service endpoint in a Sandbox.
60 |
# File 'lib/docker_engine/models/connect_request.rb', line 60 optional :endpoint_id, String, api_name: :EndpointID |
#gateway ⇒ String?
Gateway address for this network.
66 |
# File 'lib/docker_engine/models/connect_request.rb', line 66 optional :gateway, String, api_name: :Gateway |
#global_i_pv6_address ⇒ String?
Global IPv6 address.
72 |
# File 'lib/docker_engine/models/connect_request.rb', line 72 optional :global_i_pv6_address, String, api_name: :GlobalIPv6Address |
#global_i_pv6_prefix_len ⇒ Integer?
Mask length of the global IPv6 address.
78 |
# File 'lib/docker_engine/models/connect_request.rb', line 78 optional :global_i_pv6_prefix_len, Integer, api_name: :GlobalIPv6PrefixLen |
#gw_priority ⇒ Integer?
This property determines which endpoint will provide the default gateway for a container. The endpoint with the highest priority will be used. If multiple endpoints have the same priority, endpoints are lexicographically sorted based on their network name, and the one that sorts first is picked.
87 |
# File 'lib/docker_engine/models/connect_request.rb', line 87 optional :gw_priority, Integer, api_name: :GwPriority |
#i_pv6_gateway ⇒ String?
IPv6 gateway address.
114 |
# File 'lib/docker_engine/models/connect_request.rb', line 114 optional :i_pv6_gateway, String, api_name: :IPv6Gateway |
#ip_address ⇒ String?
IPv4 address.
93 |
# File 'lib/docker_engine/models/connect_request.rb', line 93 optional :ip_address, String, api_name: :IPAddress |
#ip_prefix_len ⇒ Integer?
Mask length of the IPv4 address.
108 |
# File 'lib/docker_engine/models/connect_request.rb', line 108 optional :ip_prefix_len, Integer, api_name: :IPPrefixLen |
#ipam_config ⇒ DockerEngine::Models::ConnectRequest::EndpointConfig::IpamConfig?
EndpointIPAMConfig represents an endpoint's IPAM configuration.
99 100 101 102 |
# File 'lib/docker_engine/models/connect_request.rb', line 99 optional :ipam_config, -> { DockerEngine::ConnectRequest::EndpointConfig::IpamConfig }, api_name: :IPAMConfig, nil?: true |
#links ⇒ Array<String>?
119 |
# File 'lib/docker_engine/models/connect_request.rb', line 119 optional :links, DockerEngine::Internal::Type::ArrayOf[String], api_name: :Links |
#mac_address ⇒ String?
MAC address for the endpoint on this network. The network driver might ignore this parameter.
126 |
# File 'lib/docker_engine/models/connect_request.rb', line 126 optional :mac_address, String, api_name: :MacAddress |
#network_id ⇒ String?
Unique ID of the network.
132 |
# File 'lib/docker_engine/models/connect_request.rb', line 132 optional :network_id, String, api_name: :NetworkID |