Class: DockerEngine::Models::Container::HostConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngine::Models::Container::HostConfig
- Defined in:
- lib/docker_engine/models/container.rb
Overview
Defined Under Namespace
Modules: CgroupnsMode, Isolation Classes: BlkioDeviceReadBp, BlkioDeviceReadIOp, BlkioDeviceWriteBp, BlkioDeviceWriteIOp, BlkioWeightDevice, Device, DeviceRequest, LogConfig, Mount, PortBinding, RestartPolicy, Ulimit
Instance Attribute Summary collapse
-
#annotations ⇒ Hash{Symbol=>String}?
Arbitrary non-identifying metadata attached to container and provided to the runtime when the container is started.
-
#auto_remove ⇒ Boolean?
Automatically remove the container when the container's process exits.
-
#binds ⇒ Array<String>?
A list of volume bindings for this container.
-
#blkio_device_read_bps ⇒ Array<DockerEngine::Models::Container::HostConfig::BlkioDeviceReadBp>?
Limit read rate (bytes per second) from a device, in the form:.
-
#blkio_device_read_i_ops ⇒ Array<DockerEngine::Models::Container::HostConfig::BlkioDeviceReadIOp>?
Limit read rate (IO per second) from a device, in the form:.
-
#blkio_device_write_bps ⇒ Array<DockerEngine::Models::Container::HostConfig::BlkioDeviceWriteBp>?
Limit write rate (bytes per second) to a device, in the form:.
-
#blkio_device_write_i_ops ⇒ Array<DockerEngine::Models::Container::HostConfig::BlkioDeviceWriteIOp>?
Limit write rate (IO per second) to a device, in the form:.
-
#blkio_weight ⇒ Integer?
Block IO weight (relative weight).
-
#blkio_weight_device ⇒ Array<DockerEngine::Models::Container::HostConfig::BlkioWeightDevice>?
Block IO weight (relative device weight) in the form:.
-
#cap_add ⇒ Array<String>?
A list of kernel capabilities to add to the container.
-
#cap_drop ⇒ Array<String>?
A list of kernel capabilities to drop from the container.
-
#cgroup ⇒ String?
Cgroup to use for the container.
-
#cgroup_parent ⇒ String?
Path to
cgroupsunder which the container'scgroupis created. -
#cgroupns_mode ⇒ Symbol, ...
cgroup namespace mode for the container.
-
#console_size ⇒ Array<Integer>?
Initial console size, as an
[height, width]array. -
#container_id_file ⇒ String?
Path to a file where the container ID is written.
-
#cpu_count ⇒ Integer?
The number of usable CPUs (Windows only).
-
#cpu_percent ⇒ Integer?
The usable percentage of the available CPUs (Windows only).
-
#cpu_period ⇒ Integer?
The length of a CPU period in microseconds.
-
#cpu_quota ⇒ Integer?
Microseconds of CPU time that the container can get in a CPU period.
-
#cpu_realtime_period ⇒ Integer?
The length of a CPU real-time period in microseconds.
-
#cpu_realtime_runtime ⇒ Integer?
The length of a CPU real-time runtime in microseconds.
-
#cpu_shares ⇒ Integer?
An integer value representing this container's relative CPU weight versus other containers.
-
#cpuset_cpus ⇒ String?
CPUs in which to allow execution (e.g.,
0-3,0,1). -
#cpuset_mems ⇒ String?
Memory nodes (MEMs) in which to allow execution (0-3, 0,1).
-
#device_cgroup_rules ⇒ Array<String>?
a list of cgroup rules to apply to the container.
-
#device_requests ⇒ Array<DockerEngine::Models::Container::HostConfig::DeviceRequest>?
A list of requests for devices to be sent to device drivers.
-
#devices ⇒ Array<DockerEngine::Models::Container::HostConfig::Device>?
A list of devices to add to the container.
-
#dns ⇒ Array<String>?
A list of DNS servers for the container to use.
-
#dns_options ⇒ Array<String>?
A list of DNS options.
-
#dns_search ⇒ Array<String>?
A list of DNS search domains.
-
#extra_hosts ⇒ Array<String>?
A list of hostnames/IP mappings to add to the container's
/etc/hostsfile. -
#group_add ⇒ Array<String>?
A list of additional groups that the container process will run as.
-
#init ⇒ Boolean?
Run an init inside the container that forwards signals and reaps processes.
-
#io_maximum_bandwidth ⇒ Integer?
Maximum IO in bytes per second for the container system drive (Windows only).
-
#io_maximum_i_ops ⇒ Integer?
Maximum IOps for the container system drive (Windows only).
-
#ipc_mode ⇒ String?
IPC sharing mode for the container.
-
#isolation ⇒ Symbol, ...
Isolation technology of the container.
-
#links ⇒ Array<String>?
A list of links for the container in the form
container_name:alias. -
#log_config ⇒ DockerEngine::Models::Container::HostConfig::LogConfig?
The logging configuration for this container.
-
#masked_paths ⇒ Array<String>?
The list of paths to be masked inside the container (this overrides the default set of paths).
-
#memory ⇒ Integer?
Memory limit in bytes.
-
#memory_reservation ⇒ Integer?
Memory soft limit in bytes.
-
#memory_swap ⇒ Integer?
Total memory limit (memory + swap).
-
#memory_swappiness ⇒ Integer?
Tune a container's memory swappiness behavior.
-
#mounts ⇒ Array<DockerEngine::Models::Container::HostConfig::Mount>?
Specification for mounts to be added to the container.
-
#nano_cpus ⇒ Integer?
CPU quota in units of 10-9 CPUs.
-
#network_mode ⇒ String?
Network mode to use for this container.
-
#oom_kill_disable ⇒ Boolean?
Disable OOM Killer for the container.
-
#oom_score_adj ⇒ Integer?
An integer value containing the score given to the container in order to tune OOM killer preferences.
-
#pid_mode ⇒ String?
Set the PID (Process) Namespace mode for the container.
-
#pids_limit ⇒ Integer?
Tune a container's PIDs limit.
-
#port_bindings ⇒ Hash{Symbol=>Array<DockerEngine::Models::Container::HostConfig::PortBinding>}?
PortMap describes the mapping of container ports to host ports, using the container's port-number and protocol as key in the format
<port>/<protocol>, for example,80/udp. -
#privileged ⇒ Boolean?
Gives the container full access to the host.
-
#publish_all_ports ⇒ Boolean?
Allocates an ephemeral host port for all of a container's exposed ports.
-
#readonly_paths ⇒ Array<String>?
The list of paths to be set as read-only inside the container (this overrides the default set of paths).
-
#readonly_rootfs ⇒ Boolean?
Mount the container's root filesystem as read only.
-
#restart_policy ⇒ DockerEngine::Models::Container::HostConfig::RestartPolicy?
The behavior to apply when the container exits.
-
#runtime ⇒ String?
Runtime to use with this container.
-
#security_opt ⇒ Array<String>?
A list of string values to customize labels for MLS systems, such as SELinux.
-
#shm_size ⇒ Integer?
Size of
/dev/shmin bytes. -
#storage_opt ⇒ Hash{Symbol=>String}?
Storage driver options for this container, in the form
{"size": "120G"}. -
#sysctls ⇒ Hash{Symbol=>String}?
A list of kernel parameters (sysctls) to set in the container.
-
#tmpfs ⇒ Hash{Symbol=>String}?
A map of container directories which should be replaced by tmpfs mounts, and their corresponding mount options.
-
#ulimits ⇒ Array<DockerEngine::Models::Container::HostConfig::Ulimit>?
A list of resource limits to set in the container.
-
#userns_mode ⇒ String?
Sets the usernamespace mode for the container when usernamespace remapping option is enabled.
-
#uts_mode ⇒ String?
UTS namespace to use for the container.
-
#volume_driver ⇒ String?
Driver that this container uses to mount volumes.
-
#volumes_from ⇒ Array<String>?
A list of volumes to inherit from another container, specified in the form
<container name>[:<ro|rw>].
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(host_ip: nil, host_port: nil) ⇒ Object
constructor
PortBinding represents a binding between a host IP address and a host port.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(host_ip: nil, host_port: nil) ⇒ Object
PortBinding represents a binding between a host IP address and a host port.
|
|
# File 'lib/docker_engine/models/container.rb', line 1036
|
Instance Attribute Details
#annotations ⇒ Hash{Symbol=>String}?
Arbitrary non-identifying metadata attached to container and provided to the runtime when the container is started.
300 |
# File 'lib/docker_engine/models/container.rb', line 300 optional :annotations, DockerEngine::Internal::Type::HashOf[String], api_name: :Annotations |
#auto_remove ⇒ Boolean?
Automatically remove the container when the container's process exits. This has
no effect if RestartPolicy is set.
307 |
# File 'lib/docker_engine/models/container.rb', line 307 optional :auto_remove, DockerEngine::Internal::Type::Boolean, api_name: :AutoRemove |
#binds ⇒ Array<String>?
A list of volume bindings for this container. Each volume binding is a string in one of these forms:
host-src:container-dest[:options]to bind-mount a host path into the container. Bothhost-src, andcontainer-destmust be an absolute path.volume-name:container-dest[:options]to bind-mount a volume managed by a volume driver into the container.container-destmust be an absolute path.
options is an optional, comma-delimited list of:
nocopydisables automatic copying of data from the container path to the volume. Thenocopyflag only applies to named volumes.[ro|rw]mounts a volume read-only or read-write, respectively. If omitted or set torw, volumes are mounted read-write.-
[z|Z]applies SELinux labels to allow or deny multiple containers to read and write to the same volume.z: a shared content label is applied to the content. This label indicates that multiple containers can share the volume content, for both reading and writing.Z: a private unshared label is applied to the content. This label indicates that only the current container can use a private volume. Labeling systems such as SELinux require proper labels to be placed on volume content that is mounted into a container. Without a label, the security system can prevent a container's processes from using the content. By default, the labels set by the host operating system are not modified.
[[r]shared|[r]slave|[r]private]specifies mount propagation behavior. This only applies to bind-mounted volumes, not internal volumes or named volumes. Mount propagation requires the source mount point (the location where the source directory is mounted in the host operating system) to have the correct propagation properties. For shared volumes, the source mount point must be set toshared. For slave volumes, the mount must be set to eithersharedorslave.
345 |
# File 'lib/docker_engine/models/container.rb', line 345 optional :binds, DockerEngine::Internal::Type::ArrayOf[String], api_name: :Binds |
#blkio_device_read_bps ⇒ Array<DockerEngine::Models::Container::HostConfig::BlkioDeviceReadBp>?
Limit read rate (bytes per second) from a device, in the form:
[{"Path": "device_path", "Rate": rate}]
355 356 357 358 359 |
# File 'lib/docker_engine/models/container.rb', line 355 optional :blkio_device_read_bps, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::HostConfig::BlkioDeviceReadBp] }, api_name: :BlkioDeviceReadBps |
#blkio_device_read_i_ops ⇒ Array<DockerEngine::Models::Container::HostConfig::BlkioDeviceReadIOp>?
Limit read rate (IO per second) from a device, in the form:
[{"Path": "device_path", "Rate": rate}]
369 370 371 372 373 |
# File 'lib/docker_engine/models/container.rb', line 369 optional :blkio_device_read_i_ops, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::HostConfig::BlkioDeviceReadIOp] }, api_name: :BlkioDeviceReadIOps |
#blkio_device_write_bps ⇒ Array<DockerEngine::Models::Container::HostConfig::BlkioDeviceWriteBp>?
Limit write rate (bytes per second) to a device, in the form:
[{"Path": "device_path", "Rate": rate}]
383 384 385 386 387 |
# File 'lib/docker_engine/models/container.rb', line 383 optional :blkio_device_write_bps, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::HostConfig::BlkioDeviceWriteBp] }, api_name: :BlkioDeviceWriteBps |
#blkio_device_write_i_ops ⇒ Array<DockerEngine::Models::Container::HostConfig::BlkioDeviceWriteIOp>?
Limit write rate (IO per second) to a device, in the form:
[{"Path": "device_path", "Rate": rate}]
397 398 399 400 401 |
# File 'lib/docker_engine/models/container.rb', line 397 optional :blkio_device_write_i_ops, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::HostConfig::BlkioDeviceWriteIOp] }, api_name: :BlkioDeviceWriteIOps |
#blkio_weight ⇒ Integer?
Block IO weight (relative weight).
407 |
# File 'lib/docker_engine/models/container.rb', line 407 optional :blkio_weight, Integer, api_name: :BlkioWeight |
#blkio_weight_device ⇒ Array<DockerEngine::Models::Container::HostConfig::BlkioWeightDevice>?
Block IO weight (relative device weight) in the form:
[{"Path": "device_path", "Weight": weight}]
417 418 419 420 421 |
# File 'lib/docker_engine/models/container.rb', line 417 optional :blkio_weight_device, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::HostConfig::BlkioWeightDevice] }, api_name: :BlkioWeightDevice |
#cap_add ⇒ Array<String>?
A list of kernel capabilities to add to the container. Conflicts with option 'Capabilities'.
428 |
# File 'lib/docker_engine/models/container.rb', line 428 optional :cap_add, DockerEngine::Internal::Type::ArrayOf[String], api_name: :CapAdd |
#cap_drop ⇒ Array<String>?
A list of kernel capabilities to drop from the container. Conflicts with option 'Capabilities'.
435 |
# File 'lib/docker_engine/models/container.rb', line 435 optional :cap_drop, DockerEngine::Internal::Type::ArrayOf[String], api_name: :CapDrop |
#cgroup ⇒ String?
Cgroup to use for the container.
441 |
# File 'lib/docker_engine/models/container.rb', line 441 optional :cgroup, String, api_name: :Cgroup |
#cgroup_parent ⇒ String?
Path to cgroups under which the container's cgroup is created. If the path
is not absolute, the path is considered to be relative to the cgroups path of
the init process. Cgroups are created if they do not already exist.
463 |
# File 'lib/docker_engine/models/container.rb', line 463 optional :cgroup_parent, String, api_name: :CgroupParent |
#cgroupns_mode ⇒ Symbol, ...
cgroup namespace mode for the container. Possible values are:
"private": the container runs in its own private cgroup namespace"host": use the host system's cgroup namespace
If not specified, the daemon default is used, which can either be "private" or
"host", depending on daemon version, kernel support and configuration.
453 454 455 |
# File 'lib/docker_engine/models/container.rb', line 453 optional :cgroupns_mode, enum: -> { DockerEngine::Container::HostConfig::CgroupnsMode }, api_name: :CgroupnsMode |
#console_size ⇒ Array<Integer>?
Initial console size, as an [height, width] array.
469 470 471 472 |
# File 'lib/docker_engine/models/container.rb', line 469 optional :console_size, DockerEngine::Internal::Type::ArrayOf[Integer], api_name: :ConsoleSize, nil?: true |
#container_id_file ⇒ String?
Path to a file where the container ID is written
478 |
# File 'lib/docker_engine/models/container.rb', line 478 optional :container_id_file, String, api_name: :ContainerIDFile |
#cpu_count ⇒ Integer?
The number of usable CPUs (Windows only).
On Windows Server containers, the processor resource controls are mutually
exclusive. The order of precedence is CPUCount first, then CPUShares, and
CPUPercent last.
488 |
# File 'lib/docker_engine/models/container.rb', line 488 optional :cpu_count, Integer, api_name: :CpuCount |
#cpu_percent ⇒ Integer?
The usable percentage of the available CPUs (Windows only).
On Windows Server containers, the processor resource controls are mutually
exclusive. The order of precedence is CPUCount first, then CPUShares, and
CPUPercent last.
498 |
# File 'lib/docker_engine/models/container.rb', line 498 optional :cpu_percent, Integer, api_name: :CpuPercent |
#cpu_period ⇒ Integer?
The length of a CPU period in microseconds.
504 |
# File 'lib/docker_engine/models/container.rb', line 504 optional :cpu_period, Integer, api_name: :CpuPeriod |
#cpu_quota ⇒ Integer?
Microseconds of CPU time that the container can get in a CPU period.
510 |
# File 'lib/docker_engine/models/container.rb', line 510 optional :cpu_quota, Integer, api_name: :CpuQuota |
#cpu_realtime_period ⇒ Integer?
The length of a CPU real-time period in microseconds. Set to 0 to allocate no time allocated to real-time tasks.
517 |
# File 'lib/docker_engine/models/container.rb', line 517 optional :cpu_realtime_period, Integer, api_name: :CpuRealtimePeriod |
#cpu_realtime_runtime ⇒ Integer?
The length of a CPU real-time runtime in microseconds. Set to 0 to allocate no time allocated to real-time tasks.
524 |
# File 'lib/docker_engine/models/container.rb', line 524 optional :cpu_realtime_runtime, Integer, api_name: :CpuRealtimeRuntime |
#cpu_shares ⇒ Integer?
An integer value representing this container's relative CPU weight versus other containers.
544 |
# File 'lib/docker_engine/models/container.rb', line 544 optional :cpu_shares, Integer, api_name: :CpuShares |
#cpuset_cpus ⇒ String?
CPUs in which to allow execution (e.g., 0-3, 0,1).
530 |
# File 'lib/docker_engine/models/container.rb', line 530 optional :cpuset_cpus, String, api_name: :CpusetCpus |
#cpuset_mems ⇒ String?
Memory nodes (MEMs) in which to allow execution (0-3, 0,1). Only effective on NUMA systems.
537 |
# File 'lib/docker_engine/models/container.rb', line 537 optional :cpuset_mems, String, api_name: :CpusetMems |
#device_cgroup_rules ⇒ Array<String>?
a list of cgroup rules to apply to the container
550 551 552 |
# File 'lib/docker_engine/models/container.rb', line 550 optional :device_cgroup_rules, DockerEngine::Internal::Type::ArrayOf[String], api_name: :DeviceCgroupRules |
#device_requests ⇒ Array<DockerEngine::Models::Container::HostConfig::DeviceRequest>?
A list of requests for devices to be sent to device drivers.
558 559 560 561 562 |
# File 'lib/docker_engine/models/container.rb', line 558 optional :device_requests, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::HostConfig::DeviceRequest] }, api_name: :DeviceRequests |
#devices ⇒ Array<DockerEngine::Models::Container::HostConfig::Device>?
A list of devices to add to the container.
568 569 570 |
# File 'lib/docker_engine/models/container.rb', line 568 optional :devices, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::HostConfig::Device] }, api_name: :Devices |
#dns ⇒ Array<String>?
A list of DNS servers for the container to use.
576 |
# File 'lib/docker_engine/models/container.rb', line 576 optional :dns, DockerEngine::Internal::Type::ArrayOf[String], api_name: :Dns |
#dns_options ⇒ Array<String>?
A list of DNS options.
582 |
# File 'lib/docker_engine/models/container.rb', line 582 optional :dns_options, DockerEngine::Internal::Type::ArrayOf[String], api_name: :DnsOptions |
#dns_search ⇒ Array<String>?
A list of DNS search domains.
588 |
# File 'lib/docker_engine/models/container.rb', line 588 optional :dns_search, DockerEngine::Internal::Type::ArrayOf[String], api_name: :DnsSearch |
#extra_hosts ⇒ Array<String>?
A list of hostnames/IP mappings to add to the container's /etc/hosts file.
Specified in the form ["hostname:IP"].
595 |
# File 'lib/docker_engine/models/container.rb', line 595 optional :extra_hosts, DockerEngine::Internal::Type::ArrayOf[String], api_name: :ExtraHosts |
#group_add ⇒ Array<String>?
A list of additional groups that the container process will run as.
601 |
# File 'lib/docker_engine/models/container.rb', line 601 optional :group_add, DockerEngine::Internal::Type::ArrayOf[String], api_name: :GroupAdd |
#init ⇒ Boolean?
Run an init inside the container that forwards signals and reaps processes. This field is omitted if empty, and the default (as configured on the daemon) is used.
609 |
# File 'lib/docker_engine/models/container.rb', line 609 optional :init, DockerEngine::Internal::Type::Boolean, api_name: :Init, nil?: true |
#io_maximum_bandwidth ⇒ Integer?
Maximum IO in bytes per second for the container system drive (Windows only).
615 |
# File 'lib/docker_engine/models/container.rb', line 615 optional :io_maximum_bandwidth, Integer, api_name: :IOMaximumBandwidth |
#io_maximum_i_ops ⇒ Integer?
Maximum IOps for the container system drive (Windows only)
621 |
# File 'lib/docker_engine/models/container.rb', line 621 optional :io_maximum_i_ops, Integer, api_name: :IOMaximumIOps |
#ipc_mode ⇒ String?
IPC sharing mode for the container. Possible values are:
"none": own private IPC namespace, with /dev/shm not mounted"private": own private IPC namespace"shareable": own private IPC namespace, with a possibility to share it with other containers"container:<name|id>": join another (shareable) container's IPC namespace"host": use the host system's IPC namespace
If not specified, daemon default is used, which can either be "private" or
"shareable", depending on daemon version and configuration.
637 |
# File 'lib/docker_engine/models/container.rb', line 637 optional :ipc_mode, String, api_name: :IpcMode |
#isolation ⇒ Symbol, ...
Isolation technology of the container. (Windows only)
643 |
# File 'lib/docker_engine/models/container.rb', line 643 optional :isolation, enum: -> { DockerEngine::Container::HostConfig::Isolation }, api_name: :Isolation |
#links ⇒ Array<String>?
A list of links for the container in the form container_name:alias.
649 |
# File 'lib/docker_engine/models/container.rb', line 649 optional :links, DockerEngine::Internal::Type::ArrayOf[String], api_name: :Links |
#log_config ⇒ DockerEngine::Models::Container::HostConfig::LogConfig?
The logging configuration for this container
655 |
# File 'lib/docker_engine/models/container.rb', line 655 optional :log_config, -> { DockerEngine::Container::HostConfig::LogConfig }, api_name: :LogConfig |
#masked_paths ⇒ Array<String>?
The list of paths to be masked inside the container (this overrides the default set of paths).
662 |
# File 'lib/docker_engine/models/container.rb', line 662 optional :masked_paths, DockerEngine::Internal::Type::ArrayOf[String], api_name: :MaskedPaths |
#memory ⇒ Integer?
Memory limit in bytes.
668 |
# File 'lib/docker_engine/models/container.rb', line 668 optional :memory, Integer, api_name: :Memory |
#memory_reservation ⇒ Integer?
Memory soft limit in bytes.
674 |
# File 'lib/docker_engine/models/container.rb', line 674 optional :memory_reservation, Integer, api_name: :MemoryReservation |
#memory_swap ⇒ Integer?
Total memory limit (memory + swap). Set as -1 to enable unlimited swap.
680 |
# File 'lib/docker_engine/models/container.rb', line 680 optional :memory_swap, Integer, api_name: :MemorySwap |
#memory_swappiness ⇒ Integer?
Tune a container's memory swappiness behavior. Accepts an integer between 0 and 100.
687 |
# File 'lib/docker_engine/models/container.rb', line 687 optional :memory_swappiness, Integer, api_name: :MemorySwappiness |
#mounts ⇒ Array<DockerEngine::Models::Container::HostConfig::Mount>?
Specification for mounts to be added to the container.
693 694 695 |
# File 'lib/docker_engine/models/container.rb', line 693 optional :mounts, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::HostConfig::Mount] }, api_name: :Mounts |
#nano_cpus ⇒ Integer?
CPU quota in units of 10-9 CPUs.
701 |
# File 'lib/docker_engine/models/container.rb', line 701 optional :nano_cpus, Integer, api_name: :NanoCpus |
#network_mode ⇒ String?
Network mode to use for this container. Supported standard values are: bridge,
host, none, and container:<name|id>. Any other value is taken as a custom
network's name to which this container should connect to.
709 |
# File 'lib/docker_engine/models/container.rb', line 709 optional :network_mode, String, api_name: :NetworkMode |
#oom_kill_disable ⇒ Boolean?
Disable OOM Killer for the container.
715 |
# File 'lib/docker_engine/models/container.rb', line 715 optional :oom_kill_disable, DockerEngine::Internal::Type::Boolean, api_name: :OomKillDisable |
#oom_score_adj ⇒ Integer?
An integer value containing the score given to the container in order to tune OOM killer preferences.
722 |
# File 'lib/docker_engine/models/container.rb', line 722 optional :oom_score_adj, Integer, api_name: :OomScoreAdj |
#pid_mode ⇒ String?
Set the PID (Process) Namespace mode for the container. It can be either:
"container:<name|id>": joins another container's PID namespace"host": use the host's PID namespace inside the container
731 |
# File 'lib/docker_engine/models/container.rb', line 731 optional :pid_mode, String, api_name: :PidMode |
#pids_limit ⇒ Integer?
Tune a container's PIDs limit. Set 0 or -1 for unlimited, or null to not
change.
738 |
# File 'lib/docker_engine/models/container.rb', line 738 optional :pids_limit, Integer, api_name: :PidsLimit, nil?: true |
#port_bindings ⇒ Hash{Symbol=>Array<DockerEngine::Models::Container::HostConfig::PortBinding>}?
PortMap describes the mapping of container ports to host ports, using the
container's port-number and protocol as key in the format <port>/<protocol>,
for example, 80/udp.
If a container's port is mapped for multiple protocols, separate entries are added to the mapping table.
749 750 751 752 753 |
# File 'lib/docker_engine/models/container.rb', line 749 optional :port_bindings, -> { DockerEngine::Internal::Type::HashOf[DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::HostConfig::PortBinding]] }, api_name: :PortBindings |
#privileged ⇒ Boolean?
Gives the container full access to the host.
759 |
# File 'lib/docker_engine/models/container.rb', line 759 optional :privileged, DockerEngine::Internal::Type::Boolean, api_name: :Privileged |
#publish_all_ports ⇒ Boolean?
Allocates an ephemeral host port for all of a container's exposed ports.
Ports are de-allocated when the container stops and allocated when the container starts. The allocated port might be changed when restarting the container.
The port is selected from the ephemeral port range that depends on the kernel.
For example, on Linux the range is defined by
/proc/sys/net/ipv4/ip_local_port_range.
772 |
# File 'lib/docker_engine/models/container.rb', line 772 optional :publish_all_ports, DockerEngine::Internal::Type::Boolean, api_name: :PublishAllPorts |
#readonly_paths ⇒ Array<String>?
The list of paths to be set as read-only inside the container (this overrides the default set of paths).
779 |
# File 'lib/docker_engine/models/container.rb', line 779 optional :readonly_paths, DockerEngine::Internal::Type::ArrayOf[String], api_name: :ReadonlyPaths |
#readonly_rootfs ⇒ Boolean?
Mount the container's root filesystem as read only.
785 |
# File 'lib/docker_engine/models/container.rb', line 785 optional :readonly_rootfs, DockerEngine::Internal::Type::Boolean, api_name: :ReadonlyRootfs |
#restart_policy ⇒ DockerEngine::Models::Container::HostConfig::RestartPolicy?
The behavior to apply when the container exits. The default is not to restart.
An ever increasing delay (double the previous delay, starting at 100ms) is added before each restart to prevent flooding the server.
794 795 796 |
# File 'lib/docker_engine/models/container.rb', line 794 optional :restart_policy, -> { DockerEngine::Container::HostConfig::RestartPolicy }, api_name: :RestartPolicy |
#runtime ⇒ String?
Runtime to use with this container.
802 |
# File 'lib/docker_engine/models/container.rb', line 802 optional :runtime, String, api_name: :Runtime, nil?: true |
#security_opt ⇒ Array<String>?
A list of string values to customize labels for MLS systems, such as SELinux.
808 |
# File 'lib/docker_engine/models/container.rb', line 808 optional :security_opt, DockerEngine::Internal::Type::ArrayOf[String], api_name: :SecurityOpt |
#shm_size ⇒ Integer?
Size of /dev/shm in bytes. If omitted, the system uses 64MB.
814 |
# File 'lib/docker_engine/models/container.rb', line 814 optional :shm_size, Integer, api_name: :ShmSize |
#storage_opt ⇒ Hash{Symbol=>String}?
Storage driver options for this container, in the form {"size": "120G"}.
820 |
# File 'lib/docker_engine/models/container.rb', line 820 optional :storage_opt, DockerEngine::Internal::Type::HashOf[String], api_name: :StorageOpt |
#sysctls ⇒ Hash{Symbol=>String}?
A list of kernel parameters (sysctls) to set in the container.
This field is omitted if not set.
828 |
# File 'lib/docker_engine/models/container.rb', line 828 optional :sysctls, DockerEngine::Internal::Type::HashOf[String], api_name: :Sysctls, nil?: true |
#tmpfs ⇒ Hash{Symbol=>String}?
A map of container directories which should be replaced by tmpfs mounts, and their corresponding mount options. For example:
{ "/run": "rw,noexec,nosuid,size=65536k" }
839 |
# File 'lib/docker_engine/models/container.rb', line 839 optional :tmpfs, DockerEngine::Internal::Type::HashOf[String], api_name: :Tmpfs |
#ulimits ⇒ Array<DockerEngine::Models::Container::HostConfig::Ulimit>?
A list of resource limits to set in the container. For example:
{"Name": "nofile", "Soft": 1024, "Hard": 2048}
849 850 851 |
# File 'lib/docker_engine/models/container.rb', line 849 optional :ulimits, -> { DockerEngine::Internal::Type::ArrayOf[DockerEngine::Container::HostConfig::Ulimit] }, api_name: :Ulimits |
#userns_mode ⇒ String?
Sets the usernamespace mode for the container when usernamespace remapping option is enabled.
858 |
# File 'lib/docker_engine/models/container.rb', line 858 optional :userns_mode, String, api_name: :UsernsMode |
#uts_mode ⇒ String?
UTS namespace to use for the container.
864 |
# File 'lib/docker_engine/models/container.rb', line 864 optional :uts_mode, String, api_name: :UTSMode |
#volume_driver ⇒ String?
Driver that this container uses to mount volumes.
870 |
# File 'lib/docker_engine/models/container.rb', line 870 optional :volume_driver, String, api_name: :VolumeDriver |
#volumes_from ⇒ Array<String>?
A list of volumes to inherit from another container, specified in the form
<container name>[:<ro|rw>].
877 |
# File 'lib/docker_engine/models/container.rb', line 877 optional :volumes_from, DockerEngine::Internal::Type::ArrayOf[String], api_name: :VolumesFrom |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine/models/container.rb', line 1130
|