Class: DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount
- Defined in:
- lib/docker_engine/models/container_create_params.rb
Defined Under Namespace
Modules: Type Classes: BindOptions, ImageOptions, TmpfsOptions, VolumeOptions
Instance Attribute Summary collapse
-
#bind_options ⇒ DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount::BindOptions?
Optional configuration for the
bindtype. -
#consistency ⇒ String?
The consistency requirement for the mount:
default,consistent,cached, ordelegated. -
#image_options ⇒ DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount::ImageOptions?
Optional configuration for the
imagetype. -
#read_only ⇒ Boolean?
Whether the mount should be read-only.
-
#source ⇒ String?
Mount source (e.g. a volume name, a host path).
-
#target ⇒ String?
Container path.
-
#tmpfs_options ⇒ DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount::TmpfsOptions?
Optional configuration for the
tmpfstype. -
#type ⇒ Symbol, ...
The mount type.
-
#volume_options ⇒ DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount::VolumeOptions?
Optional configuration for the
volumetype.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(mode: nil, options: nil, size_bytes: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see TmpfsOptions for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(mode: nil, options: nil, size_bytes: nil) ⇒ Object
Some parameter documentations has been truncated, see TmpfsOptions for more details.
Optional configuration for the tmpfs type.
|
|
# File 'lib/docker_engine/models/container_create_params.rb', line 1164
|
Instance Attribute Details
#bind_options ⇒ DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount::BindOptions?
Optional configuration for the bind type.
1091 1092 1093 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1091 optional :bind_options, -> { DockerEngine::ContainerCreateParams::Config::HostConfig::Mount::BindOptions }, api_name: :BindOptions |
#consistency ⇒ String?
The consistency requirement for the mount: default, consistent, cached, or
delegated.
1100 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1100 optional :consistency, String, api_name: :Consistency |
#image_options ⇒ DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount::ImageOptions?
Optional configuration for the image type.
1106 1107 1108 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1106 optional :image_options, -> { DockerEngine::ContainerCreateParams::Config::HostConfig::Mount::ImageOptions }, api_name: :ImageOptions |
#read_only ⇒ Boolean?
Whether the mount should be read-only.
1114 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1114 optional :read_only, DockerEngine::Internal::Type::Boolean, api_name: :ReadOnly |
#source ⇒ String?
Mount source (e.g. a volume name, a host path). The source cannot be specified
when using Type=tmpfs. For Type=bind, the source path must either exist, or
the CreateMountpoint must be set to true to create the source path on the
host if missing.
For Type=npipe, the pipe must exist prior to creating the container.
1125 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1125 optional :source, String, api_name: :Source |
#target ⇒ String?
Container path.
1131 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1131 optional :target, String, api_name: :Target |
#tmpfs_options ⇒ DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount::TmpfsOptions?
Optional configuration for the tmpfs type.
1137 1138 1139 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1137 optional :tmpfs_options, -> { DockerEngine::ContainerCreateParams::Config::HostConfig::Mount::TmpfsOptions }, api_name: :TmpfsOptions |
#type ⇒ Symbol, ...
The mount type. Available types:
binda mount of a file or directory from the host into the container.clustera Swarm cluster volume.imagean OCI image.npipea named pipe from the host into the container.tmpfsatmpfs.volumea docker volume with the givenName.
1152 1153 1154 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1152 optional :type, enum: -> { DockerEngine::ContainerCreateParams::Config::HostConfig::Mount::Type }, api_name: :Type |
#volume_options ⇒ DockerEngine::Models::ContainerCreateParams::Config::HostConfig::Mount::VolumeOptions?
Optional configuration for the volume type.
1160 1161 1162 |
# File 'lib/docker_engine/models/container_create_params.rb', line 1160 optional :volume_options, -> { DockerEngine::ContainerCreateParams::Config::HostConfig::Mount::VolumeOptions }, api_name: :VolumeOptions |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/docker_engine/models/container_create_params.rb', line 1262
|