Class: DockerEngine::Models::Image::Manifest::ImageData
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- DockerEngine::Models::Image::Manifest::ImageData
- Defined in:
- lib/docker_engine/models/image.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#containers ⇒ Array<String>
The IDs of the containers that are using this image.
-
#platform ⇒ DockerEngine::Models::Image::Manifest::ImageData::Platform?
Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.
- #size ⇒ DockerEngine::Models::Image::Manifest::ImageData::Size
Instance Method Summary collapse
-
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Platform for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, inspect, #inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(architecture: nil, os: nil, os_features: nil, os_version: nil, variant: nil) ⇒ Object
Some parameter documentations has been truncated, see Platform for more details.
Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.
|
|
# File 'lib/docker_engine/models/image.rb', line 1263
|
Instance Attribute Details
#containers ⇒ Array<String>
The IDs of the containers that are using this image.
1245 |
# File 'lib/docker_engine/models/image.rb', line 1245 required :containers, DockerEngine::Internal::Type::ArrayOf[String], api_name: :Containers |
#platform ⇒ DockerEngine::Models::Image::Manifest::ImageData::Platform?
Describes the platform which the image in the manifest runs on, as defined in the OCI Image Index Specification.
1253 1254 1255 1256 |
# File 'lib/docker_engine/models/image.rb', line 1253 required :platform, -> { DockerEngine::Image::Manifest::ImageData::Platform }, api_name: :Platform, nil?: true |
#size ⇒ DockerEngine::Models::Image::Manifest::ImageData::Size
1261 |
# File 'lib/docker_engine/models/image.rb', line 1261 required :size, -> { DockerEngine::Image::Manifest::ImageData::Size }, api_name: :Size |